.. _conventions:

Coding conventions
==================

scippneutron uses the same conventions as scipp.
For simplicity, they are documented only once `here <https://scipp.github.io/reference/developer/coding-conventions.html>`_.
